Sutekh Card Filters

# Card Filters for Sutekh 2.2.1

## Contents

1. Usage
2. Keyboard Navigation
3. Filter Elements
   1. Filter Group
   2. Artist
   3. Capacity
   4. Card Count
   5. Card Function
   6. Card Name
   7. Card Text
   8. Card Type
   9. Card Sets
   10. Clan
   11. Cost
   12. Cost Type
   13. Creed
   14. Discipline
   15. Discipline with Level
   16. Expansion with Rarity
   17. Group
   18. Keyword
   19. Life
   20. Path
   21. Physical Expansion
   22. Physical Printing
   23. Non-Default Printing
   24. Sect
   25. In the ‘In Use’ children of
   26. Title
   27. Virtue
4. Notes

## Usage

Filter elements and values for the filters can be dragged from the right hand pane to the filter to add them to the filter, and dragged from the filter to the right hand pane to remove them from the filter. Disabled filter elements or filter elements with no values set are ignored.

## Keyboard Navigation

You can switch between the different filter lists using <Alt>—<Left> and <Alt>—<Right>. <Ctrl>—<Enter> will paste the currently selected list of values into the filter. <Del> will delete a value or filter part from the filter <Ctrl>—<Space> will disable a filter part, while <Alt>—<Space> will negate it.

## Filter Elements

The available filtering options are listed below. The first line of each item shows the description you’ll see in the filter editor in bold. The rest of the description describes the arguments the filter takes and the results it produces.

### Filter Group

Parameters: A list of other filter elements.

Filter element with holds other filter elements. The result of the filter group is the combination of all the filter elements as specified by the Filter Group type.

The 4 Group types are:

- All of: This filter matches only if every filter in the group matches.
- Any of: This filter matches if at least one of the filters in the group matches.
- Not all of: This filter matches if at least one of the filters in the group doesn’t match.
- Not any of: This filter matches only if none of the filters in the group match.

### Artist

Parameters: a list of artists

Returns all cards where one or more of the specified artists has created art for the card.

### Capacity

Parameters: a list of capacities.

Returns all cards of the selected capacities

### Card Count

Parameters: a list of card numbers from a chosen card set (filters on number of cards in the Card Set).

Returns a list of cards that have the chosen counts in the given card set.

### Card Function

Parameters: the chosen function from the list of supported types.

Functions include roles such as unlock or bleed modifier. Returns all cards matching the given functions.

### Card Name

Parameters: the text to be matched against card names (% and _ can be used as wildcards).

Returns all cards whose name contains this string

### Card Text

Parameters: the desired card text to search for (% and _ can be used as wildcards).

Returns all cards whose text contains this string.

### Card Type

Parameters: a list of card types.

Returns all cards of the given types

### Card Sets

Parameters: a list of card sets names

Selects cards in the specified sets.

### Clan

Parameters: a list of clans

Returns all cards which require or are of the specified clans

### Cost

Parameters: a list of costs.

Returns all cards with the given costs.

### Cost Type

Parameters: a list of cost types.

Returns cards requiring the selected cost types.

### Creed

Parameters: a list of creeds.

Returns all cards requiring or of the selected creeds

### Discipline

Parameters: a list of disciplines.

Returns a list of all cards which have or require the selected disciplines.

### Discipline with Level

Parameters: a list of disciplines with levels (each element specified as a discipline with associated level, i.e. superior or inferior)

Returns all matching cards.

### Expansion with Rarity

Parameters: a list of expansions and rarities (each element specified as an expansion with associated rarity).

Returns all matching cards.

### Group

Parameters: a list of groups.

Returns all cards belonging to the listed group.

### Keyword

Parameters: a list of keywords

Returns all cards where one or more of the specified keywords is associated with the card.

### Life

Parameters: a list of life values.

Returns allies (both library and crypt cards) and retainers with the selected life. For cases where the life varies, only the base value for life is used.

### Path

Parameters: a list of paths.

Returns all cards belonging to the given paths

### Physical Expansion

Parameters: a list of expansions.

Selects cards with their expansion set to the chosen expansions. This will return all the printings in a given expansion.

### Physical Printing

Parameters: a list of printings.

Selects cards with their printing set to the chosen printings. This will only return cards with the specified printings, and will exclude cards from the same expansion that aren’t part of the given printing.

### Non-Default Printing

Parameters: a list of printings.

Returns all cards that have appeared in the specific printings.

### Sect

Parameters: a list of sects.

Returns all cards belonging to the given sects

### In the ‘In Use’ children of

Parameters: list of card sets

Selects cards in the Card Sets marked as in use that are children of the given card sets.

### Title

Parameters: a list of titles.

Returns all cards with the selected titles.

### Virtue

Parameters: a list of virtues.

Returns all cards requiring or having the selected virtues

## Notes

Using filters which require information about cards in a card set will temporarily turn off displaying cards with zero counts (for modes where this is possible) in the card list since there are no associated cards on which to base the query. Filters affected by this are: Physical Expansion, Card Sets and In Card Sets in Use.